@@ -1,10 +1,10 @@
+from musicscore.basic_functions import dToX, xToD
 from musicscore.musictree.midi import Midi
-from musicscore.musictree.treechord import TreeChord, TreeBackup
-from musicscore.musictree.treeclef import TREBLE_CLEF, BASS_CLEF, LOW_BASS_CLEF, HIGH_TREBLE_CLEF, TreeClef
+from musicscore.musictree.treechord import TreeChord
+from musicscore.musictree.treeclef import TREBLE_CLEF, BASS_CLEF, LOW_BASS_CLEF, HIGH_TREBLE_CLEF
 from musicscore.musictree.treemeasure import TreeMeasure
 from musicscore.musictree.treepart import TreePart
 from musicscore.musicxml.groups.common import Voice
-from musicscore.musicxml.types.complextypes.attributes import Clef
 from musicscore.musicxml.types.simple_type import PositiveInteger
 
 
@@ -77,17 +77,6 @@ class StreamVoice(object):
             remain = _add_to_part(remain)
 
 
-class StreamChordFormula(object):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    def condition(self, chord):
-        pass
-
-    def change_chord(self, chord):
-        pass
-
-
 class SimpleFormat(object):
     def __init__(self, quarter_durations=None, midis=None, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -97,38 +86,26 @@ class SimpleFormat(object):
         self._set_midis(midis)
         self._chords = None
 
-    @property
-    def quarter_duration(self):
-        return sum([chord.quarter_duration for chord in self.chords])
-
-    @property
-    def midis(self):
-        return [chord.midis for chord in self.chords]
-
-    @property
-    def chords(self):
-        if self._chords is None:
-            self._generate_chords()
-        return self._chords
-
+    # //private methods
     @staticmethod
     def _check_quarter_duration(quarter_durations):
         for quarter_duration in quarter_durations:
             if quarter_duration < 0:
                 raise ValueError('SimpleFormat(): wrong duration {}'.format(quarter_duration))
 
-    def _set_quarter_durations(self, quarter_durations):
-        if quarter_durations is None:
-            quarter_durations = []
+    def _generate_chords(self):
+        if self._quarter_durations == [] and self._midis == []:
+            pass
         else:
-            try:
-                quarter_durations = list(quarter_durations)
-            except TypeError:
-                quarter_durations = [quarter_durations]
+            self._chords = []
+            for i in range(len(self._quarter_durations) - len(self._midis)):
+                self._midis.append(71)
 
-        self._check_quarter_duration(quarter_durations)
+            for i in range(len(self._midis) - len(self._quarter_durations)):
+                self._quarter_durations.append(1)
 
-        self._quarter_durations = quarter_durations
+            for d, m in zip(self._quarter_durations, self._midis):
+                self._chords.append(TreeChord(m, d))
 
     def _set_midis(self, midis):
         def _is_value(x):
@@ -172,26 +149,37 @@ class SimpleFormat(object):
             else:
                 raise TypeError
 
-    def get_quarter_durations(self):
-        return [chord.quarter_duration for chord in self.chords]
+    def _set_quarter_durations(self, quarter_durations):
+        if quarter_durations is None:
+            quarter_durations = []
+        else:
+            try:
+                quarter_durations = list(quarter_durations)
+            except TypeError:
+                quarter_durations = [quarter_durations]
 
-    def get_midis(self):
+        self._check_quarter_duration(quarter_durations)
+
+        self._quarter_durations = quarter_durations
+
+    # //public properties
+    @property
+    def chords(self):
+        if self._chords is None:
+            self._generate_chords()
+        return self._chords
+
+    @property
+    def quarter_duration(self):
+        return sum([chord.quarter_duration for chord in self.chords])
+
+    @property
+    def midis(self):
         return [chord.midis for chord in self.chords]
 
-    def _generate_chords(self):
-        if self._quarter_durations == [] and self._midis == []:
-            pass
-        else:
-            self._chords = []
-            for i in range(len(self._quarter_durations) - len(self._midis)):
-                self._midis.append(71)
-
-            for i in range(len(self._midis) - len(self._quarter_durations)):
-                self._quarter_durations.append(1)
-
-            for d, m in zip(self._quarter_durations, self._midis):
-                self._chords.append(TreeChord(m, d))
+    # //public methods
 
+    # add
     def add_chord(self, chord):
         if self._chords is None:
             self._chords = []
@@ -200,17 +188,26 @@ class SimpleFormat(object):
         self._chords.append(chord)
         return chord
 
-    def to_stream_voice(self, voice_number=1):
-        output = StreamVoice(voice_number)
+    # get
+    def get_chord_dict(self, attribute):
+        output = {}
         for chord in self.chords:
-            output.add_chord(chord.__deepcopy__())
+            try:
+                output[chord] = getattr(chord, attribute)
+            except AttributeError:
+                output[chord] = None
         return output
 
-    def __deepcopy__(self, memodict={}):
-        output = SimpleFormat()
-        for chord in self.chords:
-            output.add_chord(chord.deepcopy_for_SimpleFormat())
-        return output
+    def get_midis(self):
+        return [chord.midis for chord in self.chords]
+
+    def get_quarter_durations(self):
+        return [chord.quarter_duration for chord in self.chords]
+
+    def get_quarter_positions(self):
+        return dToX(self.get_quarter_durations())
+
+    # //other
 
     def auto_clef(self, clefs=None):
         if not clefs:
@@ -253,22 +250,95 @@ class SimpleFormat(object):
                 chord.add_clef(clef)
                 current_clefs.append(clef)
 
-    def change_chord(self, *chord_formulas):
-        for formula in chord_formulas:
-            if not isinstance(formula, StreamChordFormula):
-                raise TypeError
-
+    def change_chords(self, function):
         for chord in self.chords:
-            for formula in chord_formulas:
-                if formula.condition(chord):
-                    formula.change_chord(chord)
-                    break
+            function(chord)
 
     def extend(self, simple_format):
         # self.chords
         for chord in simple_format.chords:
             self.add_chord(chord)
 
-    def transpose(self, interval):
+    def mirror(self, pivot=None):
+        if pivot is None:
+            pivot = self.chords[0].midis[0]
+        elif not isinstance(pivot, Midi):
+            pivot = Midi(pivot)
+        else:
+            pass
+
+        for midi in [m for ch in self.chords for m in ch.midis]:
+            transposition_interval = (pivot.value - midi.value) * 2
+            midi.transpose(transposition_interval)
+
+    def multiply_quarter_durations(self, factor):
+        for chord in self.chords:
+            chord.quarter_duration *= factor
+
+    @staticmethod
+    def sum(*simple_formats, no_doubles=False):
+        def _copied_position_dict(sf):
+            output = {}
+            for chord, position in zip(sf.chords, sf.get_quarter_positions()):
+                output[position] = chord.__deepcopy__()
+            return output
+
+        def _key_sorted_dict(dict):
+            output = {}
+            for key in sorted(dict.keys()):
+                output[key] = dict[key]
+            return output
+
+        def _trim_quarter_durations():
+            quarter_durations = xToD(list(all_positioned_chords.keys()))
+            chords = all_positioned_chords.values()
+            for quarter_duration, chord in zip(quarter_durations, chords):
+                chord.quarter_duration = quarter_duration
+
+        all_positioned_chords = _copied_position_dict(simple_formats[0])
+        for sf in simple_formats[1:]:
+            other_positioned_chords = _copied_position_dict(sf)
+            for other_position, other_chord in other_positioned_chords.items():
+                if other_position in all_positioned_chords.keys():
+                    chord = all_positioned_chords[other_position]
+                    if chord.is_rest:
+                        all_positioned_chords[other_position] = chord
+                    elif not other_chord.is_rest:
+                        for midi in other_chord.midis:
+                            if not no_doubles or midi.value not in [m.value for m in chord.midis]:
+                                chord.add_midi(midi)
+                    else:
+                        pass
+                else:
+                    all_positioned_chords[other_position] = other_chord
+        all_positioned_chords = _key_sorted_dict(all_positioned_chords)
+        _trim_quarter_durations()
+        output = SimpleFormat()
+        for chord in all_positioned_chords.values():
+            output.add_chord(chord)
+        return output
+
+    def retrograde(self):
+        self._chords = list(reversed(self.chords))
+
+    def to_stream_voice(self, voice_number=1):
+        output = StreamVoice(voice_number)
+        for chord in self.chords:
+            output.add_chord(chord.__deepcopy__())
+        return output
+
+    def transpose(self, interval_midi):
+        if isinstance(interval_midi, Midi):
+            interval = interval_midi.value - self.chords[0].midis[0].value
+        else:
+            interval = interval_midi
         for ch in self.chords:
             ch.transpose(interval)
+
+    # //copy
+
+    def __deepcopy__(self, memodict=None):
+        output = SimpleFormat()
+        for chord in self.chords:
+            output.add_chord(chord.deepcopy_for_SimpleFormat())
+        return output
