@@ -17,7 +17,7 @@ class Test(TestCase):
         sf_2 = SimpleFormat(quarter_durations=[2, 2, 2])
         sf.extend(sf_2)
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_1'
         self.score.write(path=result_path)
