@@ -19,13 +19,13 @@ class Test(TestCase):
         sf.chords[0].add_tie('start')
         sf.chords[1].add_tie('stop')
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
         self.score.fill_with_rest()
         self.score.preliminary_adjoin_rests()
         self.score.add_beats()
         self.score.quantize()
 
-        chord = self.score.get_measure(2).get_part(1).get_voice(1).chords[0]
+        chord = self.score.get_measure(2).get_part(1).get_staff(1).get_voice(1).chords[0]
         chord.remove_from_score()
 
         result_path = path + '_test_1'
