@@ -14,7 +14,7 @@ class Test(TestCase):
         self.score.page_style.format = 'portrait'
 
     def test_1(self):
-        sf = SimpleFormat(durations=(1.5, 0.5, 1.5))
+        sf = SimpleFormat(quarter_durations=(1.5, 0.5, 1.5))
         v = sf.to_stream_voice(1)
         self.score.set_time_signatures(times={1: (7, 8)})
         v.add_to_score(self.score)
@@ -25,7 +25,7 @@ class Test(TestCase):
         TestScore().assert_template(xml_path)
 
     def test_2(self):
-        sf = SimpleFormat(durations=(0.25, 0.25))
+        sf = SimpleFormat(quarter_durations=(0.25, 0.25))
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score)
         xml_path = path + '_test_2.xml'
@@ -35,7 +35,7 @@ class Test(TestCase):
         TestScore().assert_template(xml_path)
 
     def test_3(self):
-        sf = SimpleFormat(durations=(0.25, 0.125, 0.125, 0.25, 0.25))
+        sf = SimpleFormat(quarter_durations=(0.25, 0.125, 0.125, 0.25, 0.25))
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score)
         xml_path = path + '_test_3.xml'
