@@ -14,7 +14,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
         sf = SimpleFormat(quarter_durations=[4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4])
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
     def test_1(self):
         self.score.page_style.orientation = 'landscape'
